@@ -314,7 +314,7 @@ static bool get_proc_stat(char *pid, char *format_str, struct procstat* prs,
     /* replace the first ')' with a '\0', the contents look like this:
      *    pid (program_name) state ...
      * if we don't find ')' then it's incorrectly formated */
-    if ((paren = strchr(stat_text, ')')) == NULL) {
+    if ((paren = strrchr(stat_text, ')')) == NULL) {
         read_ok = false;
         goto done;
     }
@@ -394,7 +394,7 @@ static void eval_link(char *pid, char *link_rel, enum field field, char **ptr,
 
     /* copy the path onto our obstack, set the value (somewhere in pts)
      * and free the results of canonicalize_file_name */
-    obstack_printf(mem_pool, link);
+    obstack_printf(mem_pool, "%s", link);
     obstack_1grow(mem_pool, '\0');
 
     *ptr = (char *) obstack_finish(mem_pool);
@@ -635,7 +635,7 @@ void OS_get_table()
         bzero(prs, sizeof(struct procstat));
 
         /* intilize the format string */
-        obstack_printf(&mem_pool, get_string(STR_DEFAULT_FORMAT));
+        obstack_printf(&mem_pool, "%s", get_string(STR_DEFAULT_FORMAT));
         obstack_1grow(&mem_pool, '\0');
         format_str = (char *) obstack_finish(&mem_pool);
 
@@ -668,7 +668,8 @@ void OS_get_table()
 		calc_prec(format_str, prs, &mem_pool);
 
         /* Go ahead and bless into a perl object */
-        bless_into_proc(format_str, field_names,
+        /* Linux.h defines const char* const* Fiels, but we cast it away, as bless_into_proc only understands char** */
+        bless_into_proc(format_str, (char**) field_names,
             prs->uid,			
             prs->gid,			
             prs->pid,			
